@@ -16,30 +16,31 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 
-from google.api_core.client_options import ClientOptions
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
+from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
 except AttributeError:  # pragma: NO COVER
     OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
-from google.cloud.osconfig_v1.services.os_config_service import pagers
-from google.cloud.osconfig_v1.types import patch_deployments
-from google.cloud.osconfig_v1.types import patch_jobs
 from google.protobuf import duration_pb2  # type: ignore
 from google.protobuf import field_mask_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
-from .transports.base import OsConfigServiceTransport, DEFAULT_CLIENT_INFO
-from .transports.grpc_asyncio import OsConfigServiceGrpcAsyncIOTransport
+
+from google.cloud.osconfig_v1.services.os_config_service import pagers
+from google.cloud.osconfig_v1.types import patch_deployments, patch_jobs
+
 from .client import OsConfigServiceClient
+from .transports.base import DEFAULT_CLIENT_INFO, OsConfigServiceTransport
+from .transports.grpc_asyncio import OsConfigServiceGrpcAsyncIOTransport
 
 
 class OsConfigServiceAsyncClient:
@@ -227,14 +228,13 @@ class OsConfigServiceAsyncClient:
         r"""Patch VM instances by creating and running a patch
         job.
 
-
         .. code-block:: python
 
             from google.cloud import osconfig_v1
 
-            def sample_execute_patch_job():
+            async def sample_execute_patch_job():
                 # Create a client
-                client = osconfig_v1.OsConfigServiceClient()
+                client = osconfig_v1.OsConfigServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = osconfig_v1.ExecutePatchJobRequest(
@@ -242,7 +242,7 @@ class OsConfigServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.execute_patch_job(request=request)
+                response = await client.execute_patch_job(request=request)
 
                 # Handle the response
                 print(response)
@@ -289,7 +289,12 @@ class OsConfigServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -307,14 +312,13 @@ class OsConfigServiceAsyncClient:
         progress of an ongoing patch job or review the details
         of completed jobs.
 
-
         .. code-block:: python
 
             from google.cloud import osconfig_v1
 
-            def sample_get_patch_job():
+            async def sample_get_patch_job():
                 # Create a client
-                client = osconfig_v1.OsConfigServiceClient()
+                client = osconfig_v1.OsConfigServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = osconfig_v1.GetPatchJobRequest(
@@ -322,7 +326,7 @@ class OsConfigServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_patch_job(request=request)
+                response = await client.get_patch_job(request=request)
 
                 # Handle the response
                 print(response)
@@ -390,7 +394,12 @@ class OsConfigServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -406,14 +415,13 @@ class OsConfigServiceAsyncClient:
         r"""Cancel a patch job. The patch job must be active.
         Canceled patch jobs cannot be restarted.
 
-
         .. code-block:: python
 
             from google.cloud import osconfig_v1
 
-            def sample_cancel_patch_job():
+            async def sample_cancel_patch_job():
                 # Create a client
-                client = osconfig_v1.OsConfigServiceClient()
+                client = osconfig_v1.OsConfigServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = osconfig_v1.CancelPatchJobRequest(
@@ -421,7 +429,7 @@ class OsConfigServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.cancel_patch_job(request=request)
+                response = await client.cancel_patch_job(request=request)
 
                 # Handle the response
                 print(response)
@@ -467,7 +475,12 @@ class OsConfigServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -487,9 +500,9 @@ class OsConfigServiceAsyncClient:
 
             from google.cloud import osconfig_v1
 
-            def sample_list_patch_jobs():
+            async def sample_list_patch_jobs():
                 # Create a client
-                client = osconfig_v1.OsConfigServiceClient()
+                client = osconfig_v1.OsConfigServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = osconfig_v1.ListPatchJobsRequest(
@@ -500,7 +513,7 @@ class OsConfigServiceAsyncClient:
                 page_result = client.list_patch_jobs(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -559,12 +572,20 @@ class OsConfigServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListPatchJobsAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -585,9 +606,9 @@ class OsConfigServiceAsyncClient:
 
             from google.cloud import osconfig_v1
 
-            def sample_list_patch_job_instance_details():
+            async def sample_list_patch_job_instance_details():
                 # Create a client
-                client = osconfig_v1.OsConfigServiceClient()
+                client = osconfig_v1.OsConfigServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = osconfig_v1.ListPatchJobInstanceDetailsRequest(
@@ -598,7 +619,7 @@ class OsConfigServiceAsyncClient:
                 page_result = client.list_patch_job_instance_details(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -659,12 +680,20 @@ class OsConfigServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListPatchJobInstanceDetailsAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -687,9 +716,9 @@ class OsConfigServiceAsyncClient:
 
             from google.cloud import osconfig_v1
 
-            def sample_create_patch_deployment():
+            async def sample_create_patch_deployment():
                 # Create a client
-                client = osconfig_v1.OsConfigServiceClient()
+                client = osconfig_v1.OsConfigServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = osconfig_v1.CreatePatchDeploymentRequest(
@@ -698,7 +727,7 @@ class OsConfigServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.create_patch_deployment(request=request)
+                response = await client.create_patch_deployment(request=request)
 
                 # Handle the response
                 print(response)
@@ -787,7 +816,12 @@ class OsConfigServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -807,9 +841,9 @@ class OsConfigServiceAsyncClient:
 
             from google.cloud import osconfig_v1
 
-            def sample_get_patch_deployment():
+            async def sample_get_patch_deployment():
                 # Create a client
-                client = osconfig_v1.OsConfigServiceClient()
+                client = osconfig_v1.OsConfigServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = osconfig_v1.GetPatchDeploymentRequest(
@@ -817,7 +851,7 @@ class OsConfigServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_patch_deployment(request=request)
+                response = await client.get_patch_deployment(request=request)
 
                 # Handle the response
                 print(response)
@@ -881,7 +915,12 @@ class OsConfigServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -901,9 +940,9 @@ class OsConfigServiceAsyncClient:
 
             from google.cloud import osconfig_v1
 
-            def sample_list_patch_deployments():
+            async def sample_list_patch_deployments():
                 # Create a client
-                client = osconfig_v1.OsConfigServiceClient()
+                client = osconfig_v1.OsConfigServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = osconfig_v1.ListPatchDeploymentsRequest(
@@ -914,7 +953,7 @@ class OsConfigServiceAsyncClient:
                 page_result = client.list_patch_deployments(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -975,12 +1014,20 @@ class OsConfigServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListPatchDeploymentsAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -1001,9 +1048,9 @@ class OsConfigServiceAsyncClient:
 
             from google.cloud import osconfig_v1
 
-            def sample_delete_patch_deployment():
+            async def sample_delete_patch_deployment():
                 # Create a client
-                client = osconfig_v1.OsConfigServiceClient()
+                client = osconfig_v1.OsConfigServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = osconfig_v1.DeletePatchDeploymentRequest(
@@ -1011,7 +1058,7 @@ class OsConfigServiceAsyncClient:
                 )
 
                 # Make the request
-                client.delete_patch_deployment(request=request)
+                await client.delete_patch_deployment(request=request)
 
         Args:
             request (Union[google.cloud.osconfig_v1.types.DeletePatchDeploymentRequest, dict]):
@@ -1063,7 +1110,10 @@ class OsConfigServiceAsyncClient:
 
         # Send the request.
         await rpc(
-            request, retry=retry, timeout=timeout, metadata=metadata,
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
         )
 
     async def update_patch_deployment(
@@ -1082,16 +1132,16 @@ class OsConfigServiceAsyncClient:
 
             from google.cloud import osconfig_v1
 
-            def sample_update_patch_deployment():
+            async def sample_update_patch_deployment():
                 # Create a client
-                client = osconfig_v1.OsConfigServiceClient()
+                client = osconfig_v1.OsConfigServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = osconfig_v1.UpdatePatchDeploymentRequest(
                 )
 
                 # Make the request
-                response = client.update_patch_deployment(request=request)
+                response = await client.update_patch_deployment(request=request)
 
                 # Handle the response
                 print(response)
@@ -1167,7 +1217,12 @@ class OsConfigServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1185,14 +1240,13 @@ class OsConfigServiceAsyncClient:
         Patch deployment in paused state doesn't generate patch
         jobs.
 
-
         .. code-block:: python
 
             from google.cloud import osconfig_v1
 
-            def sample_pause_patch_deployment():
+            async def sample_pause_patch_deployment():
                 # Create a client
-                client = osconfig_v1.OsConfigServiceClient()
+                client = osconfig_v1.OsConfigServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = osconfig_v1.PausePatchDeploymentRequest(
@@ -1200,7 +1254,7 @@ class OsConfigServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.pause_patch_deployment(request=request)
+                response = await client.pause_patch_deployment(request=request)
 
                 # Handle the response
                 print(response)
@@ -1264,7 +1318,12 @@ class OsConfigServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1282,14 +1341,13 @@ class OsConfigServiceAsyncClient:
         Patch deployment in active state continues to generate
         patch jobs.
 
-
         .. code-block:: python
 
             from google.cloud import osconfig_v1
 
-            def sample_resume_patch_deployment():
+            async def sample_resume_patch_deployment():
                 # Create a client
-                client = osconfig_v1.OsConfigServiceClient()
+                client = osconfig_v1.OsConfigServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = osconfig_v1.ResumePatchDeploymentRequest(
@@ -1297,7 +1355,7 @@ class OsConfigServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.resume_patch_deployment(request=request)
+                response = await client.resume_patch_deployment(request=request)
 
                 # Handle the response
                 print(response)
@@ -1361,7 +1419,12 @@ class OsConfigServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1375,7 +1438,9 @@ class OsConfigServiceAsyncClient:
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution("google-cloud-os-config",).version,
+        gapic_version=pkg_resources.get_distribution(
+            "google-cloud-os-config",
+        ).version,
     )
 except pkg_resources.DistributionNotFound:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
