@@ -16,31 +16,32 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
+from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
 except AttributeError:  # pragma: NO COVER
     OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
-from google.cloud.osconfig_v1.services.os_config_service import pagers
-from google.cloud.osconfig_v1.types import patch_deployments
-from google.cloud.osconfig_v1.types import patch_jobs
 from google.protobuf import duration_pb2  # type: ignore
 from google.protobuf import field_mask_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
-from .transports.base import OsConfigServiceTransport, DEFAULT_CLIENT_INFO
+
+from google.cloud.osconfig_v1.services.os_config_service import pagers
+from google.cloud.osconfig_v1.types import patch_deployments, patch_jobs
+
+from .transports.base import DEFAULT_CLIENT_INFO, OsConfigServiceTransport
 from .transports.grpc import OsConfigServiceGrpcTransport
 from .transports.grpc_asyncio import OsConfigServiceGrpcAsyncIOTransport
 
@@ -59,7 +60,10 @@ class OsConfigServiceClientMeta(type):
     _transport_registry["grpc"] = OsConfigServiceGrpcTransport
     _transport_registry["grpc_asyncio"] = OsConfigServiceGrpcAsyncIOTransport
 
-    def get_transport_class(cls, label: str = None,) -> Type[OsConfigServiceTransport]:
+    def get_transport_class(
+        cls,
+        label: str = None,
+    ) -> Type[OsConfigServiceTransport]:
         """Returns an appropriate transport class.
 
         Args:
@@ -168,10 +172,16 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
         return self._transport
 
     @staticmethod
-    def instance_path(project: str, zone: str, instance: str,) -> str:
+    def instance_path(
+        project: str,
+        zone: str,
+        instance: str,
+    ) -> str:
         """Returns a fully-qualified instance string."""
         return "projects/{project}/zones/{zone}/instances/{instance}".format(
-            project=project, zone=zone, instance=instance,
+            project=project,
+            zone=zone,
+            instance=instance,
         )
 
     @staticmethod
@@ -184,10 +194,14 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def patch_deployment_path(project: str, patch_deployment: str,) -> str:
+    def patch_deployment_path(
+        project: str,
+        patch_deployment: str,
+    ) -> str:
         """Returns a fully-qualified patch_deployment string."""
         return "projects/{project}/patchDeployments/{patch_deployment}".format(
-            project=project, patch_deployment=patch_deployment,
+            project=project,
+            patch_deployment=patch_deployment,
         )
 
     @staticmethod
@@ -200,10 +214,14 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def patch_job_path(project: str, patch_job: str,) -> str:
+    def patch_job_path(
+        project: str,
+        patch_job: str,
+    ) -> str:
         """Returns a fully-qualified patch_job string."""
         return "projects/{project}/patchJobs/{patch_job}".format(
-            project=project, patch_job=patch_job,
+            project=project,
+            patch_job=patch_job,
         )
 
     @staticmethod
@@ -213,7 +231,9 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_billing_account_path(billing_account: str,) -> str:
+    def common_billing_account_path(
+        billing_account: str,
+    ) -> str:
         """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
@@ -226,9 +246,13 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_folder_path(folder: str,) -> str:
+    def common_folder_path(
+        folder: str,
+    ) -> str:
         """Returns a fully-qualified folder string."""
-        return "folders/{folder}".format(folder=folder,)
+        return "folders/{folder}".format(
+            folder=folder,
+        )
 
     @staticmethod
     def parse_common_folder_path(path: str) -> Dict[str, str]:
@@ -237,9 +261,13 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_organization_path(organization: str,) -> str:
+    def common_organization_path(
+        organization: str,
+    ) -> str:
         """Returns a fully-qualified organization string."""
-        return "organizations/{organization}".format(organization=organization,)
+        return "organizations/{organization}".format(
+            organization=organization,
+        )
 
     @staticmethod
     def parse_common_organization_path(path: str) -> Dict[str, str]:
@@ -248,9 +276,13 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_project_path(project: str,) -> str:
+    def common_project_path(
+        project: str,
+    ) -> str:
         """Returns a fully-qualified project string."""
-        return "projects/{project}".format(project=project,)
+        return "projects/{project}".format(
+            project=project,
+        )
 
     @staticmethod
     def parse_common_project_path(path: str) -> Dict[str, str]:
@@ -259,10 +291,14 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_location_path(project: str, location: str,) -> str:
+    def common_location_path(
+        project: str,
+        location: str,
+    ) -> str:
         """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
-            project=project, location=location,
+            project=project,
+            location=location,
         )
 
     @staticmethod
@@ -434,6 +470,7 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
                 quota_project_id=client_options.quota_project_id,
                 client_info=client_info,
                 always_use_jwt_access=True,
+                api_audience=client_options.api_audience,
             )
 
     def execute_patch_job(
@@ -447,7 +484,6 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
         r"""Patch VM instances by creating and running a patch
         job.
 
-
         .. code-block:: python
 
             from google.cloud import osconfig_v1
@@ -510,7 +546,12 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -528,7 +569,6 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
         progress of an ongoing patch job or review the details
         of completed jobs.
 
-
         .. code-block:: python
 
             from google.cloud import osconfig_v1
@@ -611,7 +651,12 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -627,7 +672,6 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
         r"""Cancel a patch job. The patch job must be active.
         Canceled patch jobs cannot be restarted.
 
-
         .. code-block:: python
 
             from google.cloud import osconfig_v1
@@ -689,7 +733,12 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -781,12 +830,20 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListPatchJobsPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -883,12 +940,20 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListPatchJobInstanceDetailsPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -1011,7 +1076,12 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1105,7 +1175,12 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1199,12 +1274,20 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListPatchDeploymentsPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -1287,7 +1370,10 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
 
         # Send the request.
         rpc(
-            request, retry=retry, timeout=timeout, metadata=metadata,
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
         )
 
     def update_patch_deployment(
@@ -1391,7 +1477,12 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1409,7 +1500,6 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
         Patch deployment in paused state doesn't generate patch
         jobs.
 
-
         .. code-block:: python
 
             from google.cloud import osconfig_v1
@@ -1488,7 +1578,12 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1506,7 +1601,6 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
         Patch deployment in active state continues to generate
         patch jobs.
 
-
         .. code-block:: python
 
             from google.cloud import osconfig_v1
@@ -1585,7 +1679,12 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1606,7 +1705,9 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution("google-cloud-os-config",).version,
+        gapic_version=pkg_resources.get_distribution(
+            "google-cloud-os-config",
+        ).version,
     )
 except pkg_resources.DistributionNotFound:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
