@@ -16,15 +16,15 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 
-from google.api_core.client_options import ClientOptions
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
+from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -33,18 +33,22 @@ except AttributeError:  # pragma: NO COVER
 
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
-from google.cloud.osconfig_v1.services.os_config_zonal_service import pagers
-from google.cloud.osconfig_v1.types import inventory
-from google.cloud.osconfig_v1.types import os_policy
-from google.cloud.osconfig_v1.types import os_policy_assignment_reports
-from google.cloud.osconfig_v1.types import os_policy_assignments
-from google.cloud.osconfig_v1.types import vulnerability
 from google.protobuf import empty_pb2  # type: ignore
 from google.protobuf import field_mask_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
-from .transports.base import OsConfigZonalServiceTransport, DEFAULT_CLIENT_INFO
-from .transports.grpc_asyncio import OsConfigZonalServiceGrpcAsyncIOTransport
+
+from google.cloud.osconfig_v1.services.os_config_zonal_service import pagers
+from google.cloud.osconfig_v1.types import (
+    inventory,
+    os_policy,
+    os_policy_assignment_reports,
+    os_policy_assignments,
+    vulnerability,
+)
+
 from .client import OsConfigZonalServiceClient
+from .transports.base import DEFAULT_CLIENT_INFO, OsConfigZonalServiceTransport
+from .transports.grpc_asyncio import OsConfigZonalServiceGrpcAsyncIOTransport
 
 
 class OsConfigZonalServiceAsyncClient:
@@ -267,14 +271,13 @@ class OsConfigZonalServiceAsyncClient:
         For more information, see `Method:
         projects.locations.osPolicyAssignments.operations.cancel <https://cloud.google.com/compute/docs/osconfig/rest/v1/projects.locations.osPolicyAssignments.operations/cancel>`__.
 
-
         .. code-block:: python
 
             from google.cloud import osconfig_v1
 
-            def sample_create_os_policy_assignment():
+            async def sample_create_os_policy_assignment():
                 # Create a client
-                client = osconfig_v1.OsConfigZonalServiceClient()
+                client = osconfig_v1.OsConfigZonalServiceAsyncClient()
 
                 # Initialize request argument(s)
                 os_policy_assignment = osconfig_v1.OSPolicyAssignment()
@@ -296,7 +299,7 @@ class OsConfigZonalServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -396,7 +399,12 @@ class OsConfigZonalServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -432,14 +440,13 @@ class OsConfigZonalServiceAsyncClient:
         For more information, see `Method:
         projects.locations.osPolicyAssignments.operations.cancel <https://cloud.google.com/compute/docs/osconfig/rest/v1/projects.locations.osPolicyAssignments.operations/cancel>`__.
 
-
         .. code-block:: python
 
             from google.cloud import osconfig_v1
 
-            def sample_update_os_policy_assignment():
+            async def sample_update_os_policy_assignment():
                 # Create a client
-                client = osconfig_v1.OsConfigZonalServiceClient()
+                client = osconfig_v1.OsConfigZonalServiceAsyncClient()
 
                 # Initialize request argument(s)
                 os_policy_assignment = osconfig_v1.OSPolicyAssignment()
@@ -459,7 +466,7 @@ class OsConfigZonalServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -543,7 +550,12 @@ class OsConfigZonalServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -571,14 +583,13 @@ class OsConfigZonalServiceAsyncClient:
         retrieve a previous revision of the assignment, also provide the
         revision ID in the ``name`` parameter.
 
-
         .. code-block:: python
 
             from google.cloud import osconfig_v1
 
-            def sample_get_os_policy_assignment():
+            async def sample_get_os_policy_assignment():
                 # Create a client
-                client = osconfig_v1.OsConfigZonalServiceClient()
+                client = osconfig_v1.OsConfigZonalServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = osconfig_v1.GetOSPolicyAssignmentRequest(
@@ -586,7 +597,7 @@ class OsConfigZonalServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_os_policy_assignment(request=request)
+                response = await client.get_os_policy_assignment(request=request)
 
                 # Handle the response
                 print(response)
@@ -658,7 +669,12 @@ class OsConfigZonalServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -679,14 +695,13 @@ class OsConfigZonalServiceAsyncClient:
         For each OS policy assignment, the latest revision is
         returned.
 
-
         .. code-block:: python
 
             from google.cloud import osconfig_v1
 
-            def sample_list_os_policy_assignments():
+            async def sample_list_os_policy_assignments():
                 # Create a client
-                client = osconfig_v1.OsConfigZonalServiceClient()
+                client = osconfig_v1.OsConfigZonalServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = osconfig_v1.ListOSPolicyAssignmentsRequest(
@@ -697,7 +712,7 @@ class OsConfigZonalServiceAsyncClient:
                 page_result = client.list_os_policy_assignments(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -756,12 +771,20 @@ class OsConfigZonalServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListOSPolicyAssignmentsAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -781,14 +804,13 @@ class OsConfigZonalServiceAsyncClient:
         r"""List the OS policy assignment revisions for a given
         OS policy assignment.
 
-
         .. code-block:: python
 
             from google.cloud import osconfig_v1
 
-            def sample_list_os_policy_assignment_revisions():
+            async def sample_list_os_policy_assignment_revisions():
                 # Create a client
-                client = osconfig_v1.OsConfigZonalServiceClient()
+                client = osconfig_v1.OsConfigZonalServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = osconfig_v1.ListOSPolicyAssignmentRevisionsRequest(
@@ -799,7 +821,7 @@ class OsConfigZonalServiceAsyncClient:
                 page_result = client.list_os_policy_assignment_revisions(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -860,12 +882,20 @@ class OsConfigZonalServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListOSPolicyAssignmentRevisionsAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -896,14 +926,13 @@ class OsConfigZonalServiceAsyncClient:
         For more information, see `Method:
         projects.locations.osPolicyAssignments.operations.cancel <https://cloud.google.com/compute/docs/osconfig/rest/v1/projects.locations.osPolicyAssignments.operations/cancel>`__.
 
-
         .. code-block:: python
 
             from google.cloud import osconfig_v1
 
-            def sample_delete_os_policy_assignment():
+            async def sample_delete_os_policy_assignment():
                 # Create a client
-                client = osconfig_v1.OsConfigZonalServiceClient()
+                client = osconfig_v1.OsConfigZonalServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = osconfig_v1.DeleteOSPolicyAssignmentRequest(
@@ -915,7 +944,7 @@ class OsConfigZonalServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -952,9 +981,6 @@ class OsConfigZonalServiceAsyncClient:
 
                       }
 
-                   The JSON representation for Empty is empty JSON
-                   object {}.
-
         """
         # Create or coerce a protobuf request object.
         # Quick check: If we got a request object, we should *not* have
@@ -988,7 +1014,12 @@ class OsConfigZonalServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -1015,14 +1046,13 @@ class OsConfigZonalServiceAsyncClient:
         r"""Get the OS policy asssignment report for the
         specified Compute Engine VM instance.
 
-
         .. code-block:: python
 
             from google.cloud import osconfig_v1
 
-            def sample_get_os_policy_assignment_report():
+            async def sample_get_os_policy_assignment_report():
                 # Create a client
-                client = osconfig_v1.OsConfigZonalServiceClient()
+                client = osconfig_v1.OsConfigZonalServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = osconfig_v1.GetOSPolicyAssignmentReportRequest(
@@ -1030,7 +1060,7 @@ class OsConfigZonalServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_os_policy_assignment_report(request=request)
+                response = await client.get_os_policy_assignment_report(request=request)
 
                 # Handle the response
                 print(response)
@@ -1102,7 +1132,12 @@ class OsConfigZonalServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1121,14 +1156,13 @@ class OsConfigZonalServiceAsyncClient:
         r"""List OS policy asssignment reports for all Compute
         Engine VM instances in the specified zone.
 
-
         .. code-block:: python
 
             from google.cloud import osconfig_v1
 
-            def sample_list_os_policy_assignment_reports():
+            async def sample_list_os_policy_assignment_reports():
                 # Create a client
-                client = osconfig_v1.OsConfigZonalServiceClient()
+                client = osconfig_v1.OsConfigZonalServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = osconfig_v1.ListOSPolicyAssignmentReportsRequest(
@@ -1139,7 +1173,7 @@ class OsConfigZonalServiceAsyncClient:
                 page_result = client.list_os_policy_assignment_reports(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -1227,12 +1261,20 @@ class OsConfigZonalServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListOSPolicyAssignmentReportsAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -1250,14 +1292,13 @@ class OsConfigZonalServiceAsyncClient:
         r"""Get inventory data for the specified VM instance. If the VM has
         no associated inventory, the message ``NOT_FOUND`` is returned.
 
-
         .. code-block:: python
 
             from google.cloud import osconfig_v1
 
-            def sample_get_inventory():
+            async def sample_get_inventory():
                 # Create a client
-                client = osconfig_v1.OsConfigZonalServiceClient()
+                client = osconfig_v1.OsConfigZonalServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = osconfig_v1.GetInventoryRequest(
@@ -1265,7 +1306,7 @@ class OsConfigZonalServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_inventory(request=request)
+                response = await client.get_inventory(request=request)
 
                 # Handle the response
                 print(response)
@@ -1340,7 +1381,12 @@ class OsConfigZonalServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1357,14 +1403,13 @@ class OsConfigZonalServiceAsyncClient:
         r"""List inventory data for all VM instances in the
         specified zone.
 
-
         .. code-block:: python
 
             from google.cloud import osconfig_v1
 
-            def sample_list_inventories():
+            async def sample_list_inventories():
                 # Create a client
-                client = osconfig_v1.OsConfigZonalServiceClient()
+                client = osconfig_v1.OsConfigZonalServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = osconfig_v1.ListInventoriesRequest(
@@ -1375,7 +1420,7 @@ class OsConfigZonalServiceAsyncClient:
                 page_result = client.list_inventories(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -1442,12 +1487,20 @@ class OsConfigZonalServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListInventoriesAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -1466,14 +1519,13 @@ class OsConfigZonalServiceAsyncClient:
         instance. Only VMs with inventory data have
         vulnerability reports associated with them.
 
-
         .. code-block:: python
 
             from google.cloud import osconfig_v1
 
-            def sample_get_vulnerability_report():
+            async def sample_get_vulnerability_report():
                 # Create a client
-                client = osconfig_v1.OsConfigZonalServiceClient()
+                client = osconfig_v1.OsConfigZonalServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = osconfig_v1.GetVulnerabilityReportRequest(
@@ -1481,7 +1533,7 @@ class OsConfigZonalServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_vulnerability_report(request=request)
+                response = await client.get_vulnerability_report(request=request)
 
                 # Handle the response
                 print(response)
@@ -1552,7 +1604,12 @@ class OsConfigZonalServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1569,14 +1626,13 @@ class OsConfigZonalServiceAsyncClient:
         r"""List vulnerability reports for all VM instances in
         the specified zone.
 
-
         .. code-block:: python
 
             from google.cloud import osconfig_v1
 
-            def sample_list_vulnerability_reports():
+            async def sample_list_vulnerability_reports():
                 # Create a client
-                client = osconfig_v1.OsConfigZonalServiceClient()
+                client = osconfig_v1.OsConfigZonalServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = osconfig_v1.ListVulnerabilityReportsRequest(
@@ -1587,7 +1643,7 @@ class OsConfigZonalServiceAsyncClient:
                 page_result = client.list_vulnerability_reports(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -1655,12 +1711,20 @@ class OsConfigZonalServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListVulnerabilityReportsAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -1675,7 +1739,9 @@ class OsConfigZonalServiceAsyncClient:
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution("google-cloud-os-config",).version,
+        gapic_version=pkg_resources.get_distribution(
+            "google-cloud-os-config",
+        ).version,
     )
 except pkg_resources.DistributionNotFound:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
