@@ -16,18 +16,18 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
+from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -36,16 +36,20 @@ except AttributeError:  # pragma: NO COVER
 
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
-from google.cloud.osconfig_v1.services.os_config_zonal_service import pagers
-from google.cloud.osconfig_v1.types import inventory
-from google.cloud.osconfig_v1.types import os_policy
-from google.cloud.osconfig_v1.types import os_policy_assignment_reports
-from google.cloud.osconfig_v1.types import os_policy_assignments
-from google.cloud.osconfig_v1.types import vulnerability
 from google.protobuf import empty_pb2  # type: ignore
 from google.protobuf import field_mask_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
-from .transports.base import OsConfigZonalServiceTransport, DEFAULT_CLIENT_INFO
+
+from google.cloud.osconfig_v1.services.os_config_zonal_service import pagers
+from google.cloud.osconfig_v1.types import (
+    inventory,
+    os_policy,
+    os_policy_assignment_reports,
+    os_policy_assignments,
+    vulnerability,
+)
+
+from .transports.base import DEFAULT_CLIENT_INFO, OsConfigZonalServiceTransport
 from .transports.grpc import OsConfigZonalServiceGrpcTransport
 from .transports.grpc_asyncio import OsConfigZonalServiceGrpcAsyncIOTransport
 
@@ -65,7 +69,8 @@ class OsConfigZonalServiceClientMeta(type):
     _transport_registry["grpc_asyncio"] = OsConfigZonalServiceGrpcAsyncIOTransport
 
     def get_transport_class(
-        cls, label: str = None,
+        cls,
+        label: str = None,
     ) -> Type[OsConfigZonalServiceTransport]:
         """Returns an appropriate transport class.
 
@@ -175,10 +180,16 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         return self._transport
 
     @staticmethod
-    def instance_path(project: str, zone: str, instance: str,) -> str:
+    def instance_path(
+        project: str,
+        zone: str,
+        instance: str,
+    ) -> str:
         """Returns a fully-qualified instance string."""
         return "projects/{project}/zones/{zone}/instances/{instance}".format(
-            project=project, zone=zone, instance=instance,
+            project=project,
+            zone=zone,
+            instance=instance,
         )
 
     @staticmethod
@@ -192,7 +203,10 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
 
     @staticmethod
     def instance_os_policy_assignment_path(
-        project: str, location: str, instance: str, assignment: str,
+        project: str,
+        location: str,
+        instance: str,
+        assignment: str,
     ) -> str:
         """Returns a fully-qualified instance_os_policy_assignment string."""
         return "projects/{project}/locations/{location}/instances/{instance}/osPolicyAssignments/{assignment}".format(
@@ -212,10 +226,16 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def inventory_path(project: str, location: str, instance: str,) -> str:
+    def inventory_path(
+        project: str,
+        location: str,
+        instance: str,
+    ) -> str:
         """Returns a fully-qualified inventory string."""
         return "projects/{project}/locations/{location}/instances/{instance}/inventory".format(
-            project=project, location=location, instance=instance,
+            project=project,
+            location=location,
+            instance=instance,
         )
 
     @staticmethod
@@ -229,7 +249,9 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
 
     @staticmethod
     def os_policy_assignment_path(
-        project: str, location: str, os_policy_assignment: str,
+        project: str,
+        location: str,
+        os_policy_assignment: str,
     ) -> str:
         """Returns a fully-qualified os_policy_assignment string."""
         return "projects/{project}/locations/{location}/osPolicyAssignments/{os_policy_assignment}".format(
@@ -249,7 +271,10 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
 
     @staticmethod
     def os_policy_assignment_report_path(
-        project: str, location: str, instance: str, assignment: str,
+        project: str,
+        location: str,
+        instance: str,
+        assignment: str,
     ) -> str:
         """Returns a fully-qualified os_policy_assignment_report string."""
         return "projects/{project}/locations/{location}/instances/{instance}/osPolicyAssignments/{assignment}/report".format(
@@ -269,10 +294,16 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def vulnerability_report_path(project: str, location: str, instance: str,) -> str:
+    def vulnerability_report_path(
+        project: str,
+        location: str,
+        instance: str,
+    ) -> str:
         """Returns a fully-qualified vulnerability_report string."""
         return "projects/{project}/locations/{location}/instances/{instance}/vulnerabilityReport".format(
-            project=project, location=location, instance=instance,
+            project=project,
+            location=location,
+            instance=instance,
         )
 
     @staticmethod
@@ -285,7 +316,9 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_billing_account_path(billing_account: str,) -> str:
+    def common_billing_account_path(
+        billing_account: str,
+    ) -> str:
         """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
@@ -298,9 +331,13 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_folder_path(folder: str,) -> str:
+    def common_folder_path(
+        folder: str,
+    ) -> str:
         """Returns a fully-qualified folder string."""
-        return "folders/{folder}".format(folder=folder,)
+        return "folders/{folder}".format(
+            folder=folder,
+        )
 
     @staticmethod
     def parse_common_folder_path(path: str) -> Dict[str, str]:
@@ -309,9 +346,13 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_organization_path(organization: str,) -> str:
+    def common_organization_path(
+        organization: str,
+    ) -> str:
         """Returns a fully-qualified organization string."""
-        return "organizations/{organization}".format(organization=organization,)
+        return "organizations/{organization}".format(
+            organization=organization,
+        )
 
     @staticmethod
     def parse_common_organization_path(path: str) -> Dict[str, str]:
@@ -320,9 +361,13 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_project_path(project: str,) -> str:
+    def common_project_path(
+        project: str,
+    ) -> str:
         """Returns a fully-qualified project string."""
-        return "projects/{project}".format(project=project,)
+        return "projects/{project}".format(
+            project=project,
+        )
 
     @staticmethod
     def parse_common_project_path(path: str) -> Dict[str, str]:
@@ -331,10 +376,14 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_location_path(project: str, location: str,) -> str:
+    def common_location_path(
+        project: str,
+        location: str,
+    ) -> str:
         """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
-            project=project, location=location,
+            project=project,
+            location=location,
         )
 
     @staticmethod
@@ -506,6 +555,7 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
                 quota_project_id=client_options.quota_project_id,
                 client_info=client_info,
                 always_use_jwt_access=True,
+                api_audience=client_options.api_audience,
             )
 
     def create_os_policy_assignment(
@@ -533,7 +583,6 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         For more information, see `Method:
         projects.locations.osPolicyAssignments.operations.cancel <https://cloud.google.com/compute/docs/osconfig/rest/v1/projects.locations.osPolicyAssignments.operations/cancel>`__.
 
-
         .. code-block:: python
 
             from google.cloud import osconfig_v1
@@ -666,7 +715,12 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -702,7 +756,6 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         For more information, see `Method:
         projects.locations.osPolicyAssignments.operations.cancel <https://cloud.google.com/compute/docs/osconfig/rest/v1/projects.locations.osPolicyAssignments.operations/cancel>`__.
 
-
         .. code-block:: python
 
             from google.cloud import osconfig_v1
@@ -817,7 +870,12 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -845,7 +903,6 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         retrieve a previous revision of the assignment, also provide the
         revision ID in the ``name`` parameter.
 
-
         .. code-block:: python
 
             from google.cloud import osconfig_v1
@@ -932,7 +989,12 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -953,7 +1015,6 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         For each OS policy assignment, the latest revision is
         returned.
 
-
         .. code-block:: python
 
             from google.cloud import osconfig_v1
@@ -1034,12 +1095,20 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListOSPolicyAssignmentsPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -1059,7 +1128,6 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         r"""List the OS policy assignment revisions for a given
         OS policy assignment.
 
-
         .. code-block:: python
 
             from google.cloud import osconfig_v1
@@ -1144,12 +1212,20 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListOSPolicyAssignmentRevisionsPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -1180,7 +1256,6 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         For more information, see `Method:
         projects.locations.osPolicyAssignments.operations.cancel <https://cloud.google.com/compute/docs/osconfig/rest/v1/projects.locations.osPolicyAssignments.operations/cancel>`__.
 
-
         .. code-block:: python
 
             from google.cloud import osconfig_v1
@@ -1236,9 +1311,6 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
 
                       }
 
-                   The JSON representation for Empty is empty JSON
-                   object {}.
-
         """
         # Create or coerce a protobuf request object.
         # Quick check: If we got a request object, we should *not* have
@@ -1276,7 +1348,12 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -1303,7 +1380,6 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         r"""Get the OS policy asssignment report for the
         specified Compute Engine VM instance.
 
-
         .. code-block:: python
 
             from google.cloud import osconfig_v1
@@ -1394,7 +1470,12 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1413,7 +1494,6 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         r"""List OS policy asssignment reports for all Compute
         Engine VM instances in the specified zone.
 
-
         .. code-block:: python
 
             from google.cloud import osconfig_v1
@@ -1523,12 +1603,20 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListOSPolicyAssignmentReportsPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -1546,7 +1634,6 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         r"""Get inventory data for the specified VM instance. If the VM has
         no associated inventory, the message ``NOT_FOUND`` is returned.
 
-
         .. code-block:: python
 
             from google.cloud import osconfig_v1
@@ -1636,7 +1723,12 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1653,7 +1745,6 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         r"""List inventory data for all VM instances in the
         specified zone.
 
-
         .. code-block:: python
 
             from google.cloud import osconfig_v1
@@ -1738,12 +1829,20 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListInventoriesPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -1762,7 +1861,6 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         instance. Only VMs with inventory data have
         vulnerability reports associated with them.
 
-
         .. code-block:: python
 
             from google.cloud import osconfig_v1
@@ -1848,7 +1946,12 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1865,7 +1968,6 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         r"""List vulnerability reports for all VM instances in
         the specified zone.
 
-
         .. code-block:: python
 
             from google.cloud import osconfig_v1
@@ -1953,12 +2055,20 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListVulnerabilityReportsPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -1980,7 +2090,9 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution("google-cloud-os-config",).version,
+        gapic_version=pkg_resources.get_distribution(
+            "google-cloud-os-config",
+        ).version,
     )
 except pkg_resources.DistributionNotFound:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
