@@ -15,8 +15,12 @@
 #
 import proto  # type: ignore
 
-
-__protobuf__ = proto.module(package="google.cloud.osconfig.v1", manifest={"OSPolicy",},)
+__protobuf__ = proto.module(
+    package="google.cloud.osconfig.v1",
+    manifest={
+        "OSPolicy",
+    },
+)
 
 
 class OSPolicy(proto.Message):
@@ -81,8 +85,14 @@ class OSPolicy(proto.Message):
                 An empty string matches all OS versions.
         """
 
-        os_short_name = proto.Field(proto.STRING, number=1,)
-        os_version = proto.Field(proto.STRING, number=2,)
+        os_short_name = proto.Field(
+            proto.STRING,
+            number=1,
+        )
+        os_version = proto.Field(
+            proto.STRING,
+            number=2,
+        )
 
     class Resource(proto.Message):
         r"""An OS policy resource is used to define the desired state
@@ -172,8 +182,14 @@ class OSPolicy(proto.Message):
                         SHA256 checksum of the remote file.
                 """
 
-                uri = proto.Field(proto.STRING, number=1,)
-                sha256_checksum = proto.Field(proto.STRING, number=2,)
+                uri = proto.Field(
+                    proto.STRING,
+                    number=1,
+                )
+                sha256_checksum = proto.Field(
+                    proto.STRING,
+                    number=2,
+                )
 
             class Gcs(proto.Message):
                 r"""Specifies a file available as a Cloud Storage Object.
@@ -188,9 +204,18 @@ class OSPolicy(proto.Message):
                         object.
                 """
 
-                bucket = proto.Field(proto.STRING, number=1,)
-                object_ = proto.Field(proto.STRING, number=2,)
-                generation = proto.Field(proto.INT64, number=3,)
+                bucket = proto.Field(
+                    proto.STRING,
+                    number=1,
+                )
+                object_ = proto.Field(
+                    proto.STRING,
+                    number=2,
+                )
+                generation = proto.Field(
+                    proto.INT64,
+                    number=3,
+                )
 
             remote = proto.Field(
                 proto.MESSAGE,
@@ -204,8 +229,15 @@ class OSPolicy(proto.Message):
                 oneof="type",
                 message="OSPolicy.Resource.File.Gcs",
             )
-            local_path = proto.Field(proto.STRING, number=3, oneof="type",)
-            allow_insecure = proto.Field(proto.BOOL, number=4,)
+            local_path = proto.Field(
+                proto.STRING,
+                number=3,
+                oneof="type",
+            )
+            allow_insecure = proto.Field(
+                proto.BOOL,
+                number=4,
+            )
 
         class PackageResource(proto.Message):
             r"""A resource that manages a system package.
@@ -275,9 +307,14 @@ class OSPolicy(proto.Message):
                 """
 
                 source = proto.Field(
-                    proto.MESSAGE, number=1, message="OSPolicy.Resource.File",
+                    proto.MESSAGE,
+                    number=1,
+                    message="OSPolicy.Resource.File",
+                )
+                pull_deps = proto.Field(
+                    proto.BOOL,
+                    number=2,
                 )
-                pull_deps = proto.Field(proto.BOOL, number=2,)
 
             class APT(proto.Message):
                 r"""A package managed by APT.
@@ -290,7 +327,10 @@ class OSPolicy(proto.Message):
                         Required. Package name.
                 """
 
-                name = proto.Field(proto.STRING, number=1,)
+                name = proto.Field(
+                    proto.STRING,
+                    number=1,
+                )
 
             class RPM(proto.Message):
                 r"""An RPM package file. RPM packages only support INSTALLED
@@ -309,9 +349,14 @@ class OSPolicy(proto.Message):
                 """
 
                 source = proto.Field(
-                    proto.MESSAGE, number=1, message="OSPolicy.Resource.File",
+                    proto.MESSAGE,
+                    number=1,
+                    message="OSPolicy.Resource.File",
+                )
+                pull_deps = proto.Field(
+                    proto.BOOL,
+                    number=2,
                 )
-                pull_deps = proto.Field(proto.BOOL, number=2,)
 
             class YUM(proto.Message):
                 r"""A package managed by YUM.
@@ -324,7 +369,10 @@ class OSPolicy(proto.Message):
                         Required. Package name.
                 """
 
-                name = proto.Field(proto.STRING, number=1,)
+                name = proto.Field(
+                    proto.STRING,
+                    number=1,
+                )
 
             class Zypper(proto.Message):
                 r"""A package managed by Zypper.
@@ -337,7 +385,10 @@ class OSPolicy(proto.Message):
                         Required. Package name.
                 """
 
-                name = proto.Field(proto.STRING, number=1,)
+                name = proto.Field(
+                    proto.STRING,
+                    number=1,
+                )
 
             class GooGet(proto.Message):
                 r"""A package managed by GooGet.
@@ -350,7 +401,10 @@ class OSPolicy(proto.Message):
                         Required. Package name.
                 """
 
-                name = proto.Field(proto.STRING, number=1,)
+                name = proto.Field(
+                    proto.STRING,
+                    number=1,
+                )
 
             class MSI(proto.Message):
                 r"""An MSI package. MSI packages only support INSTALLED state.
@@ -365,9 +419,14 @@ class OSPolicy(proto.Message):
                 """
 
                 source = proto.Field(
-                    proto.MESSAGE, number=1, message="OSPolicy.Resource.File",
+                    proto.MESSAGE,
+                    number=1,
+                    message="OSPolicy.Resource.File",
+                )
+                properties = proto.RepeatedField(
+                    proto.STRING,
+                    number=2,
                 )
-                properties = proto.RepeatedField(proto.STRING, number=2,)
 
             desired_state = proto.Field(
                 proto.ENUM,
@@ -479,10 +538,22 @@ class OSPolicy(proto.Message):
                     number=1,
                     enum="OSPolicy.Resource.RepositoryResource.AptRepository.ArchiveType",
                 )
-                uri = proto.Field(proto.STRING, number=2,)
-                distribution = proto.Field(proto.STRING, number=3,)
-                components = proto.RepeatedField(proto.STRING, number=4,)
-                gpg_key = proto.Field(proto.STRING, number=5,)
+                uri = proto.Field(
+                    proto.STRING,
+                    number=2,
+                )
+                distribution = proto.Field(
+                    proto.STRING,
+                    number=3,
+                )
+                components = proto.RepeatedField(
+                    proto.STRING,
+                    number=4,
+                )
+                gpg_key = proto.Field(
+                    proto.STRING,
+                    number=5,
+                )
 
             class YumRepository(proto.Message):
                 r"""Represents a single yum package repository. These are added to a
@@ -505,10 +576,22 @@ class OSPolicy(proto.Message):
                         URIs of GPG keys.
                 """
 
-                id = proto.Field(proto.STRING, number=1,)
-                display_name = proto.Field(proto.STRING, number=2,)
-                base_url = proto.Field(proto.STRING, number=3,)
-                gpg_keys = proto.RepeatedField(proto.STRING, number=4,)
+                id = proto.Field(
+                    proto.STRING,
+                    number=1,
+                )
+                display_name = proto.Field(
+                    proto.STRING,
+                    number=2,
+                )
+                base_url = proto.Field(
+                    proto.STRING,
+                    number=3,
+                )
+                gpg_keys = proto.RepeatedField(
+                    proto.STRING,
+                    number=4,
+                )
 
             class ZypperRepository(proto.Message):
                 r"""Represents a single zypper package repository. These are added to a
@@ -531,10 +614,22 @@ class OSPolicy(proto.Message):
                         URIs of GPG keys.
                 """
 
-                id = proto.Field(proto.STRING, number=1,)
-                display_name = proto.Field(proto.STRING, number=2,)
-                base_url = proto.Field(proto.STRING, number=3,)
-                gpg_keys = proto.RepeatedField(proto.STRING, number=4,)
+                id = proto.Field(
+                    proto.STRING,
+                    number=1,
+                )
+                display_name = proto.Field(
+                    proto.STRING,
+                    number=2,
+                )
+                base_url = proto.Field(
+                    proto.STRING,
+                    number=3,
+                )
+                gpg_keys = proto.RepeatedField(
+                    proto.STRING,
+                    number=4,
+                )
 
             class GooRepository(proto.Message):
                 r"""Represents a Goo package repository. These are added to a repo file
@@ -548,8 +643,14 @@ class OSPolicy(proto.Message):
                         Required. The url of the repository.
                 """
 
-                name = proto.Field(proto.STRING, number=1,)
-                url = proto.Field(proto.STRING, number=2,)
+                name = proto.Field(
+                    proto.STRING,
+                    number=1,
+                )
+                url = proto.Field(
+                    proto.STRING,
+                    number=2,
+                )
 
             apt = proto.Field(
                 proto.MESSAGE,
@@ -669,20 +770,34 @@ class OSPolicy(proto.Message):
                     oneof="source",
                     message="OSPolicy.Resource.File",
                 )
-                script = proto.Field(proto.STRING, number=2, oneof="source",)
-                args = proto.RepeatedField(proto.STRING, number=3,)
+                script = proto.Field(
+                    proto.STRING,
+                    number=2,
+                    oneof="source",
+                )
+                args = proto.RepeatedField(
+                    proto.STRING,
+                    number=3,
+                )
                 interpreter = proto.Field(
                     proto.ENUM,
                     number=4,
                     enum="OSPolicy.Resource.ExecResource.Exec.Interpreter",
                 )
-                output_file_path = proto.Field(proto.STRING, number=5,)
+                output_file_path = proto.Field(
+                    proto.STRING,
+                    number=5,
+                )
 
             validate = proto.Field(
-                proto.MESSAGE, number=1, message="OSPolicy.Resource.ExecResource.Exec",
+                proto.MESSAGE,
+                number=1,
+                message="OSPolicy.Resource.ExecResource.Exec",
             )
             enforce = proto.Field(
-                proto.MESSAGE, number=2, message="OSPolicy.Resource.ExecResource.Exec",
+                proto.MESSAGE,
+                number=2,
+                message="OSPolicy.Resource.ExecResource.Exec",
             )
 
         class FileResource(proto.Message):
@@ -742,16 +857,29 @@ class OSPolicy(proto.Message):
                 oneof="source",
                 message="OSPolicy.Resource.File",
             )
-            content = proto.Field(proto.STRING, number=2, oneof="source",)
-            path = proto.Field(proto.STRING, number=3,)
+            content = proto.Field(
+                proto.STRING,
+                number=2,
+                oneof="source",
+            )
+            path = proto.Field(
+                proto.STRING,
+                number=3,
+            )
             state = proto.Field(
                 proto.ENUM,
                 number=4,
                 enum="OSPolicy.Resource.FileResource.DesiredState",
             )
-            permissions = proto.Field(proto.STRING, number=5,)
+            permissions = proto.Field(
+                proto.STRING,
+                number=5,
+            )
 
-        id = proto.Field(proto.STRING, number=1,)
+        id = proto.Field(
+            proto.STRING,
+            number=1,
+        )
         pkg = proto.Field(
             proto.MESSAGE,
             number=2,
@@ -810,19 +938,38 @@ class OSPolicy(proto.Message):
         """
 
         inventory_filters = proto.RepeatedField(
-            proto.MESSAGE, number=1, message="OSPolicy.InventoryFilter",
+            proto.MESSAGE,
+            number=1,
+            message="OSPolicy.InventoryFilter",
         )
         resources = proto.RepeatedField(
-            proto.MESSAGE, number=2, message="OSPolicy.Resource",
+            proto.MESSAGE,
+            number=2,
+            message="OSPolicy.Resource",
         )
 
-    id = proto.Field(proto.STRING, number=1,)
-    description = proto.Field(proto.STRING, number=2,)
-    mode = proto.Field(proto.ENUM, number=3, enum=Mode,)
+    id = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    description = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    mode = proto.Field(
+        proto.ENUM,
+        number=3,
+        enum=Mode,
+    )
     resource_groups = proto.RepeatedField(
-        proto.MESSAGE, number=4, message=ResourceGroup,
+        proto.MESSAGE,
+        number=4,
+        message=ResourceGroup,
+    )
+    allow_no_resource_group_match = proto.Field(
+        proto.BOOL,
+        number=5,
     )
-    allow_no_resource_group_match = proto.Field(proto.BOOL, number=5,)
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
