@@ -13,12 +13,11 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from google.protobuf import duration_pb2  # type: ignore
+from google.protobuf import timestamp_pb2  # type: ignore
 import proto  # type: ignore
 
 from google.cloud.osconfig_v1.types import osconfig_common
-from google.protobuf import duration_pb2  # type: ignore
-from google.protobuf import timestamp_pb2  # type: ignore
-
 
 __protobuf__ = proto.module(
     package="google.cloud.osconfig.v1",
@@ -80,16 +79,42 @@ class ExecutePatchJobRequest(proto.Message):
             Rollout strategy of the patch job.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    description = proto.Field(proto.STRING, number=2,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    description = proto.Field(
+        proto.STRING,
+        number=2,
+    )
     instance_filter = proto.Field(
-        proto.MESSAGE, number=7, message="PatchInstanceFilter",
+        proto.MESSAGE,
+        number=7,
+        message="PatchInstanceFilter",
+    )
+    patch_config = proto.Field(
+        proto.MESSAGE,
+        number=4,
+        message="PatchConfig",
+    )
+    duration = proto.Field(
+        proto.MESSAGE,
+        number=5,
+        message=duration_pb2.Duration,
+    )
+    dry_run = proto.Field(
+        proto.BOOL,
+        number=6,
+    )
+    display_name = proto.Field(
+        proto.STRING,
+        number=8,
+    )
+    rollout = proto.Field(
+        proto.MESSAGE,
+        number=9,
+        message="PatchRollout",
     )
-    patch_config = proto.Field(proto.MESSAGE, number=4, message="PatchConfig",)
-    duration = proto.Field(proto.MESSAGE, number=5, message=duration_pb2.Duration,)
-    dry_run = proto.Field(proto.BOOL, number=6,)
-    display_name = proto.Field(proto.STRING, number=8,)
-    rollout = proto.Field(proto.MESSAGE, number=9, message="PatchRollout",)
 
 
 class GetPatchJobRequest(proto.Message):
@@ -101,7 +126,10 @@ class GetPatchJobRequest(proto.Message):
             ``projects/*/patchJobs/*``
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class ListPatchJobInstanceDetailsRequest(proto.Message):
@@ -125,10 +153,22 @@ class ListPatchJobInstanceDetailsRequest(proto.Message):
             zone, name, state, or ``failure_reason``.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    page_size = proto.Field(proto.INT32, number=2,)
-    page_token = proto.Field(proto.STRING, number=3,)
-    filter = proto.Field(proto.STRING, number=4,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    page_size = proto.Field(
+        proto.INT32,
+        number=2,
+    )
+    page_token = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    filter = proto.Field(
+        proto.STRING,
+        number=4,
+    )
 
 
 class ListPatchJobInstanceDetailsResponse(proto.Message):
@@ -148,9 +188,14 @@ class ListPatchJobInstanceDetailsResponse(proto.Message):
         return self
 
     patch_job_instance_details = proto.RepeatedField(
-        proto.MESSAGE, number=1, message="PatchJobInstanceDetails",
+        proto.MESSAGE,
+        number=1,
+        message="PatchJobInstanceDetails",
+    )
+    next_page_token = proto.Field(
+        proto.STRING,
+        number=2,
     )
-    next_page_token = proto.Field(proto.STRING, number=2,)
 
 
 class PatchJobInstanceDetails(proto.Message):
@@ -176,11 +221,27 @@ class PatchJobInstanceDetails(proto.Message):
             attempts to apply the patch.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    instance_system_id = proto.Field(proto.STRING, number=2,)
-    state = proto.Field(proto.ENUM, number=3, enum="Instance.PatchState",)
-    failure_reason = proto.Field(proto.STRING, number=4,)
-    attempt_count = proto.Field(proto.INT64, number=5,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    instance_system_id = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    state = proto.Field(
+        proto.ENUM,
+        number=3,
+        enum="Instance.PatchState",
+    )
+    failure_reason = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    attempt_count = proto.Field(
+        proto.INT64,
+        number=5,
+    )
 
 
 class ListPatchJobsRequest(proto.Message):
@@ -202,10 +263,22 @@ class ListPatchJobsRequest(proto.Message):
             filtering is only available on the patch_deployment field.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    page_size = proto.Field(proto.INT32, number=2,)
-    page_token = proto.Field(proto.STRING, number=3,)
-    filter = proto.Field(proto.STRING, number=4,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    page_size = proto.Field(
+        proto.INT32,
+        number=2,
+    )
+    page_token = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    filter = proto.Field(
+        proto.STRING,
+        number=4,
+    )
 
 
 class ListPatchJobsResponse(proto.Message):
@@ -223,8 +296,15 @@ class ListPatchJobsResponse(proto.Message):
     def raw_page(self):
         return self
 
-    patch_jobs = proto.RepeatedField(proto.MESSAGE, number=1, message="PatchJob",)
-    next_page_token = proto.Field(proto.STRING, number=2,)
+    patch_jobs = proto.RepeatedField(
+        proto.MESSAGE,
+        number=1,
+        message="PatchJob",
+    )
+    next_page_token = proto.Field(
+        proto.STRING,
+        number=2,
+    )
 
 
 class PatchJob(proto.Message):
@@ -342,41 +422,135 @@ class PatchJob(proto.Message):
                 communicate with the service.
         """
 
-        pending_instance_count = proto.Field(proto.INT64, number=1,)
-        inactive_instance_count = proto.Field(proto.INT64, number=2,)
-        notified_instance_count = proto.Field(proto.INT64, number=3,)
-        started_instance_count = proto.Field(proto.INT64, number=4,)
-        downloading_patches_instance_count = proto.Field(proto.INT64, number=5,)
-        applying_patches_instance_count = proto.Field(proto.INT64, number=6,)
-        rebooting_instance_count = proto.Field(proto.INT64, number=7,)
-        succeeded_instance_count = proto.Field(proto.INT64, number=8,)
-        succeeded_reboot_required_instance_count = proto.Field(proto.INT64, number=9,)
-        failed_instance_count = proto.Field(proto.INT64, number=10,)
-        acked_instance_count = proto.Field(proto.INT64, number=11,)
-        timed_out_instance_count = proto.Field(proto.INT64, number=12,)
-        pre_patch_step_instance_count = proto.Field(proto.INT64, number=13,)
-        post_patch_step_instance_count = proto.Field(proto.INT64, number=14,)
-        no_agent_detected_instance_count = proto.Field(proto.INT64, number=15,)
+        pending_instance_count = proto.Field(
+            proto.INT64,
+            number=1,
+        )
+        inactive_instance_count = proto.Field(
+            proto.INT64,
+            number=2,
+        )
+        notified_instance_count = proto.Field(
+            proto.INT64,
+            number=3,
+        )
+        started_instance_count = proto.Field(
+            proto.INT64,
+            number=4,
+        )
+        downloading_patches_instance_count = proto.Field(
+            proto.INT64,
+            number=5,
+        )
+        applying_patches_instance_count = proto.Field(
+            proto.INT64,
+            number=6,
+        )
+        rebooting_instance_count = proto.Field(
+            proto.INT64,
+            number=7,
+        )
+        succeeded_instance_count = proto.Field(
+            proto.INT64,
+            number=8,
+        )
+        succeeded_reboot_required_instance_count = proto.Field(
+            proto.INT64,
+            number=9,
+        )
+        failed_instance_count = proto.Field(
+            proto.INT64,
+            number=10,
+        )
+        acked_instance_count = proto.Field(
+            proto.INT64,
+            number=11,
+        )
+        timed_out_instance_count = proto.Field(
+            proto.INT64,
+            number=12,
+        )
+        pre_patch_step_instance_count = proto.Field(
+            proto.INT64,
+            number=13,
+        )
+        post_patch_step_instance_count = proto.Field(
+            proto.INT64,
+            number=14,
+        )
+        no_agent_detected_instance_count = proto.Field(
+            proto.INT64,
+            number=15,
+        )
 
-    name = proto.Field(proto.STRING, number=1,)
-    display_name = proto.Field(proto.STRING, number=14,)
-    description = proto.Field(proto.STRING, number=2,)
-    create_time = proto.Field(proto.MESSAGE, number=3, message=timestamp_pb2.Timestamp,)
-    update_time = proto.Field(proto.MESSAGE, number=4, message=timestamp_pb2.Timestamp,)
-    state = proto.Field(proto.ENUM, number=5, enum=State,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    display_name = proto.Field(
+        proto.STRING,
+        number=14,
+    )
+    description = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    create_time = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message=timestamp_pb2.Timestamp,
+    )
+    update_time = proto.Field(
+        proto.MESSAGE,
+        number=4,
+        message=timestamp_pb2.Timestamp,
+    )
+    state = proto.Field(
+        proto.ENUM,
+        number=5,
+        enum=State,
+    )
     instance_filter = proto.Field(
-        proto.MESSAGE, number=13, message="PatchInstanceFilter",
+        proto.MESSAGE,
+        number=13,
+        message="PatchInstanceFilter",
+    )
+    patch_config = proto.Field(
+        proto.MESSAGE,
+        number=7,
+        message="PatchConfig",
+    )
+    duration = proto.Field(
+        proto.MESSAGE,
+        number=8,
+        message=duration_pb2.Duration,
     )
-    patch_config = proto.Field(proto.MESSAGE, number=7, message="PatchConfig",)
-    duration = proto.Field(proto.MESSAGE, number=8, message=duration_pb2.Duration,)
     instance_details_summary = proto.Field(
-        proto.MESSAGE, number=9, message=InstanceDetailsSummary,
+        proto.MESSAGE,
+        number=9,
+        message=InstanceDetailsSummary,
+    )
+    dry_run = proto.Field(
+        proto.BOOL,
+        number=10,
+    )
+    error_message = proto.Field(
+        proto.STRING,
+        number=11,
+    )
+    percent_complete = proto.Field(
+        proto.DOUBLE,
+        number=12,
+    )
+    patch_deployment = proto.Field(
+        proto.STRING,
+        number=15,
+    )
+    rollout = proto.Field(
+        proto.MESSAGE,
+        number=16,
+        message="PatchRollout",
     )
-    dry_run = proto.Field(proto.BOOL, number=10,)
-    error_message = proto.Field(proto.STRING, number=11,)
-    percent_complete = proto.Field(proto.DOUBLE, number=12,)
-    patch_deployment = proto.Field(proto.STRING, number=15,)
-    rollout = proto.Field(proto.MESSAGE, number=16, message="PatchRollout",)
 
 
 class PatchConfig(proto.Message):
@@ -417,22 +591,54 @@ class PatchConfig(proto.Message):
         ALWAYS = 2
         NEVER = 3
 
-    reboot_config = proto.Field(proto.ENUM, number=1, enum=RebootConfig,)
-    apt = proto.Field(proto.MESSAGE, number=3, message="AptSettings",)
-    yum = proto.Field(proto.MESSAGE, number=4, message="YumSettings",)
-    goo = proto.Field(proto.MESSAGE, number=5, message="GooSettings",)
-    zypper = proto.Field(proto.MESSAGE, number=6, message="ZypperSettings",)
+    reboot_config = proto.Field(
+        proto.ENUM,
+        number=1,
+        enum=RebootConfig,
+    )
+    apt = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message="AptSettings",
+    )
+    yum = proto.Field(
+        proto.MESSAGE,
+        number=4,
+        message="YumSettings",
+    )
+    goo = proto.Field(
+        proto.MESSAGE,
+        number=5,
+        message="GooSettings",
+    )
+    zypper = proto.Field(
+        proto.MESSAGE,
+        number=6,
+        message="ZypperSettings",
+    )
     windows_update = proto.Field(
-        proto.MESSAGE, number=7, message="WindowsUpdateSettings",
+        proto.MESSAGE,
+        number=7,
+        message="WindowsUpdateSettings",
+    )
+    pre_step = proto.Field(
+        proto.MESSAGE,
+        number=8,
+        message="ExecStep",
+    )
+    post_step = proto.Field(
+        proto.MESSAGE,
+        number=9,
+        message="ExecStep",
+    )
+    mig_instances_allowed = proto.Field(
+        proto.BOOL,
+        number=10,
     )
-    pre_step = proto.Field(proto.MESSAGE, number=8, message="ExecStep",)
-    post_step = proto.Field(proto.MESSAGE, number=9, message="ExecStep",)
-    mig_instances_allowed = proto.Field(proto.BOOL, number=10,)
 
 
 class Instance(proto.Message):
-    r"""Namespace for instance state enums.
-    """
+    r"""Namespace for instance state enums."""
 
     class PatchState(proto.Enum):
         r"""Patch state of an instance."""
@@ -463,7 +669,10 @@ class CancelPatchJobRequest(proto.Message):
             ``projects/*/patchJobs/*``
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class AptSettings(proto.Message):
@@ -493,9 +702,19 @@ class AptSettings(proto.Message):
         DIST = 1
         UPGRADE = 2
 
-    type_ = proto.Field(proto.ENUM, number=1, enum=Type,)
-    excludes = proto.RepeatedField(proto.STRING, number=2,)
-    exclusive_packages = proto.RepeatedField(proto.STRING, number=3,)
+    type_ = proto.Field(
+        proto.ENUM,
+        number=1,
+        enum=Type,
+    )
+    excludes = proto.RepeatedField(
+        proto.STRING,
+        number=2,
+    )
+    exclusive_packages = proto.RepeatedField(
+        proto.STRING,
+        number=3,
+    )
 
 
 class YumSettings(proto.Message):
@@ -522,15 +741,26 @@ class YumSettings(proto.Message):
             fields.
     """
 
-    security = proto.Field(proto.BOOL, number=1,)
-    minimal = proto.Field(proto.BOOL, number=2,)
-    excludes = proto.RepeatedField(proto.STRING, number=3,)
-    exclusive_packages = proto.RepeatedField(proto.STRING, number=4,)
+    security = proto.Field(
+        proto.BOOL,
+        number=1,
+    )
+    minimal = proto.Field(
+        proto.BOOL,
+        number=2,
+    )
+    excludes = proto.RepeatedField(
+        proto.STRING,
+        number=3,
+    )
+    exclusive_packages = proto.RepeatedField(
+        proto.STRING,
+        number=4,
+    )
 
 
 class GooSettings(proto.Message):
-    r"""Googet patching is performed by running ``googet update``.
-    """
+    r"""Googet patching is performed by running ``googet update``."""
 
 
 class ZypperSettings(proto.Message):
@@ -559,12 +789,30 @@ class ZypperSettings(proto.Message):
             with any other patch configuration fields.
     """
 
-    with_optional = proto.Field(proto.BOOL, number=1,)
-    with_update = proto.Field(proto.BOOL, number=2,)
-    categories = proto.RepeatedField(proto.STRING, number=3,)
-    severities = proto.RepeatedField(proto.STRING, number=4,)
-    excludes = proto.RepeatedField(proto.STRING, number=5,)
-    exclusive_patches = proto.RepeatedField(proto.STRING, number=6,)
+    with_optional = proto.Field(
+        proto.BOOL,
+        number=1,
+    )
+    with_update = proto.Field(
+        proto.BOOL,
+        number=2,
+    )
+    categories = proto.RepeatedField(
+        proto.STRING,
+        number=3,
+    )
+    severities = proto.RepeatedField(
+        proto.STRING,
+        number=4,
+    )
+    excludes = proto.RepeatedField(
+        proto.STRING,
+        number=5,
+    )
+    exclusive_patches = proto.RepeatedField(
+        proto.STRING,
+        number=6,
+    )
 
 
 class WindowsUpdateSettings(proto.Message):
@@ -599,9 +847,19 @@ class WindowsUpdateSettings(proto.Message):
         UPDATE_ROLLUP = 8
         UPDATE = 9
 
-    classifications = proto.RepeatedField(proto.ENUM, number=1, enum=Classification,)
-    excludes = proto.RepeatedField(proto.STRING, number=2,)
-    exclusive_patches = proto.RepeatedField(proto.STRING, number=3,)
+    classifications = proto.RepeatedField(
+        proto.ENUM,
+        number=1,
+        enum=Classification,
+    )
+    excludes = proto.RepeatedField(
+        proto.STRING,
+        number=2,
+    )
+    exclusive_patches = proto.RepeatedField(
+        proto.STRING,
+        number=3,
+    )
 
 
 class ExecStep(proto.Message):
@@ -617,10 +875,14 @@ class ExecStep(proto.Message):
     """
 
     linux_exec_step_config = proto.Field(
-        proto.MESSAGE, number=1, message="ExecStepConfig",
+        proto.MESSAGE,
+        number=1,
+        message="ExecStepConfig",
     )
     windows_exec_step_config = proto.Field(
-        proto.MESSAGE, number=2, message="ExecStepConfig",
+        proto.MESSAGE,
+        number=2,
+        message="ExecStepConfig",
     )
 
 
@@ -661,12 +923,26 @@ class ExecStepConfig(proto.Message):
         SHELL = 1
         POWERSHELL = 2
 
-    local_path = proto.Field(proto.STRING, number=1, oneof="executable",)
+    local_path = proto.Field(
+        proto.STRING,
+        number=1,
+        oneof="executable",
+    )
     gcs_object = proto.Field(
-        proto.MESSAGE, number=2, oneof="executable", message="GcsObject",
+        proto.MESSAGE,
+        number=2,
+        oneof="executable",
+        message="GcsObject",
+    )
+    allowed_success_codes = proto.RepeatedField(
+        proto.INT32,
+        number=3,
+    )
+    interpreter = proto.Field(
+        proto.ENUM,
+        number=4,
+        enum=Interpreter,
     )
-    allowed_success_codes = proto.RepeatedField(proto.INT32, number=3,)
-    interpreter = proto.Field(proto.ENUM, number=4, enum=Interpreter,)
 
 
 class GcsObject(proto.Message):
@@ -684,9 +960,18 @@ class GcsObject(proto.Message):
             change.
     """
 
-    bucket = proto.Field(proto.STRING, number=1,)
-    object_ = proto.Field(proto.STRING, number=2,)
-    generation_number = proto.Field(proto.INT64, number=3,)
+    bucket = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    object_ = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    generation_number = proto.Field(
+        proto.INT64,
+        number=3,
+    )
 
 
 class PatchInstanceFilter(proto.Message):
@@ -732,19 +1017,39 @@ class PatchInstanceFilter(proto.Message):
         and ``app=web``.
 
         Attributes:
-            labels (Sequence[google.cloud.osconfig_v1.types.PatchInstanceFilter.GroupLabel.LabelsEntry]):
+            labels (Mapping[str, str]):
                 Compute Engine instance labels that must be
                 present for a VM instance to be targeted by this
                 filter.
         """
 
-        labels = proto.MapField(proto.STRING, proto.STRING, number=1,)
+        labels = proto.MapField(
+            proto.STRING,
+            proto.STRING,
+            number=1,
+        )
 
-    all_ = proto.Field(proto.BOOL, number=1,)
-    group_labels = proto.RepeatedField(proto.MESSAGE, number=2, message=GroupLabel,)
-    zones = proto.RepeatedField(proto.STRING, number=3,)
-    instances = proto.RepeatedField(proto.STRING, number=4,)
-    instance_name_prefixes = proto.RepeatedField(proto.STRING, number=5,)
+    all_ = proto.Field(
+        proto.BOOL,
+        number=1,
+    )
+    group_labels = proto.RepeatedField(
+        proto.MESSAGE,
+        number=2,
+        message=GroupLabel,
+    )
+    zones = proto.RepeatedField(
+        proto.STRING,
+        number=3,
+    )
+    instances = proto.RepeatedField(
+        proto.STRING,
+        number=4,
+    )
+    instance_name_prefixes = proto.RepeatedField(
+        proto.STRING,
+        number=5,
+    )
 
 
 class PatchRollout(proto.Message):
@@ -792,9 +1097,15 @@ class PatchRollout(proto.Message):
         ZONE_BY_ZONE = 1
         CONCURRENT_ZONES = 2
 
-    mode = proto.Field(proto.ENUM, number=1, enum=Mode,)
+    mode = proto.Field(
+        proto.ENUM,
+        number=1,
+        enum=Mode,
+    )
     disruption_budget = proto.Field(
-        proto.MESSAGE, number=2, message=osconfig_common.FixedOrPercent,
+        proto.MESSAGE,
+        number=2,
+        message=osconfig_common.FixedOrPercent,
     )
 
 
