@@ -16,16 +16,16 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 import warnings
 
-from google.api_core.client_options import ClientOptions
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
+from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -34,20 +34,24 @@ except AttributeError:  # pragma: NO COVER
 
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
-from google.cloud.osconfig_v1alpha.services.os_config_zonal_service import pagers
-from google.cloud.osconfig_v1alpha.types import config_common
-from google.cloud.osconfig_v1alpha.types import instance_os_policies_compliance
-from google.cloud.osconfig_v1alpha.types import inventory
-from google.cloud.osconfig_v1alpha.types import os_policy
-from google.cloud.osconfig_v1alpha.types import os_policy_assignment_reports
-from google.cloud.osconfig_v1alpha.types import os_policy_assignments
-from google.cloud.osconfig_v1alpha.types import vulnerability
 from google.protobuf import empty_pb2  # type: ignore
 from google.protobuf import field_mask_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
-from .transports.base import OsConfigZonalServiceTransport, DEFAULT_CLIENT_INFO
-from .transports.grpc_asyncio import OsConfigZonalServiceGrpcAsyncIOTransport
+
+from google.cloud.osconfig_v1alpha.services.os_config_zonal_service import pagers
+from google.cloud.osconfig_v1alpha.types import (
+    config_common,
+    instance_os_policies_compliance,
+    inventory,
+    os_policy,
+    os_policy_assignment_reports,
+    os_policy_assignments,
+    vulnerability,
+)
+
 from .client import OsConfigZonalServiceClient
+from .transports.base import DEFAULT_CLIENT_INFO, OsConfigZonalServiceTransport
+from .transports.grpc_asyncio import OsConfigZonalServiceGrpcAsyncIOTransport
 
 
 class OsConfigZonalServiceAsyncClient:
@@ -276,14 +280,13 @@ class OsConfigZonalServiceAsyncClient:
         For more information, see `Method:
         projects.locations.osPolicyAssignments.operations.cancel <https://cloud.google.com/compute/docs/osconfig/rest/v1alpha/projects.locations.osPolicyAssignments.operations/cancel>`__.
 
-
         .. code-block:: python
 
             from google.cloud import osconfig_v1alpha
 
-            def sample_create_os_policy_assignment():
+            async def sample_create_os_policy_assignment():
                 # Create a client
-                client = osconfig_v1alpha.OsConfigZonalServiceClient()
+                client = osconfig_v1alpha.OsConfigZonalServiceAsyncClient()
 
                 # Initialize request argument(s)
                 os_policy_assignment = osconfig_v1alpha.OSPolicyAssignment()
@@ -305,7 +308,7 @@ class OsConfigZonalServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -405,7 +408,12 @@ class OsConfigZonalServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -441,14 +449,13 @@ class OsConfigZonalServiceAsyncClient:
         For more information, see `Method:
         projects.locations.osPolicyAssignments.operations.cancel <https://cloud.google.com/compute/docs/osconfig/rest/v1alpha/projects.locations.osPolicyAssignments.operations/cancel>`__.
 
-
         .. code-block:: python
 
             from google.cloud import osconfig_v1alpha
 
-            def sample_update_os_policy_assignment():
+            async def sample_update_os_policy_assignment():
                 # Create a client
-                client = osconfig_v1alpha.OsConfigZonalServiceClient()
+                client = osconfig_v1alpha.OsConfigZonalServiceAsyncClient()
 
                 # Initialize request argument(s)
                 os_policy_assignment = osconfig_v1alpha.OSPolicyAssignment()
@@ -468,7 +475,7 @@ class OsConfigZonalServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -552,7 +559,12 @@ class OsConfigZonalServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -580,14 +592,13 @@ class OsConfigZonalServiceAsyncClient:
         retrieve a previous revision of the assignment, also provide the
         revision ID in the ``name`` parameter.
 
-
         .. code-block:: python
 
             from google.cloud import osconfig_v1alpha
 
-            def sample_get_os_policy_assignment():
+            async def sample_get_os_policy_assignment():
                 # Create a client
-                client = osconfig_v1alpha.OsConfigZonalServiceClient()
+                client = osconfig_v1alpha.OsConfigZonalServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = osconfig_v1alpha.GetOSPolicyAssignmentRequest(
@@ -595,7 +606,7 @@ class OsConfigZonalServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_os_policy_assignment(request=request)
+                response = await client.get_os_policy_assignment(request=request)
 
                 # Handle the response
                 print(response)
@@ -667,7 +678,12 @@ class OsConfigZonalServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -688,14 +704,13 @@ class OsConfigZonalServiceAsyncClient:
         For each OS policy assignment, the latest revision is
         returned.
 
-
         .. code-block:: python
 
             from google.cloud import osconfig_v1alpha
 
-            def sample_list_os_policy_assignments():
+            async def sample_list_os_policy_assignments():
                 # Create a client
-                client = osconfig_v1alpha.OsConfigZonalServiceClient()
+                client = osconfig_v1alpha.OsConfigZonalServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = osconfig_v1alpha.ListOSPolicyAssignmentsRequest(
@@ -706,7 +721,7 @@ class OsConfigZonalServiceAsyncClient:
                 page_result = client.list_os_policy_assignments(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -765,12 +780,20 @@ class OsConfigZonalServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListOSPolicyAssignmentsAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -790,14 +813,13 @@ class OsConfigZonalServiceAsyncClient:
         r"""List the OS policy assignment revisions for a given
         OS policy assignment.
 
-
         .. code-block:: python
 
             from google.cloud import osconfig_v1alpha
 
-            def sample_list_os_policy_assignment_revisions():
+            async def sample_list_os_policy_assignment_revisions():
                 # Create a client
-                client = osconfig_v1alpha.OsConfigZonalServiceClient()
+                client = osconfig_v1alpha.OsConfigZonalServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = osconfig_v1alpha.ListOSPolicyAssignmentRevisionsRequest(
@@ -808,7 +830,7 @@ class OsConfigZonalServiceAsyncClient:
                 page_result = client.list_os_policy_assignment_revisions(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -869,12 +891,20 @@ class OsConfigZonalServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListOSPolicyAssignmentRevisionsAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -905,14 +935,13 @@ class OsConfigZonalServiceAsyncClient:
         For more information, see `Method:
         projects.locations.osPolicyAssignments.operations.cancel <https://cloud.google.com/compute/docs/osconfig/rest/v1alpha/projects.locations.osPolicyAssignments.operations/cancel>`__.
 
-
         .. code-block:: python
 
             from google.cloud import osconfig_v1alpha
 
-            def sample_delete_os_policy_assignment():
+            async def sample_delete_os_policy_assignment():
                 # Create a client
-                client = osconfig_v1alpha.OsConfigZonalServiceClient()
+                client = osconfig_v1alpha.OsConfigZonalServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = osconfig_v1alpha.DeleteOSPolicyAssignmentRequest(
@@ -924,7 +953,7 @@ class OsConfigZonalServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -961,9 +990,6 @@ class OsConfigZonalServiceAsyncClient:
 
                       }
 
-                   The JSON representation for Empty is empty JSON
-                   object {}.
-
         """
         # Create or coerce a protobuf request object.
         # Quick check: If we got a request object, we should *not* have
@@ -997,7 +1023,12 @@ class OsConfigZonalServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -1024,14 +1055,13 @@ class OsConfigZonalServiceAsyncClient:
         r"""Get OS policies compliance data for the specified
         Compute Engine VM instance.
 
-
         .. code-block:: python
 
             from google.cloud import osconfig_v1alpha
 
-            def sample_get_instance_os_policies_compliance():
+            async def sample_get_instance_os_policies_compliance():
                 # Create a client
-                client = osconfig_v1alpha.OsConfigZonalServiceClient()
+                client = osconfig_v1alpha.OsConfigZonalServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = osconfig_v1alpha.GetInstanceOSPoliciesComplianceRequest(
@@ -1039,7 +1069,7 @@ class OsConfigZonalServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_instance_os_policies_compliance(request=request)
+                response = await client.get_instance_os_policies_compliance(request=request)
 
                 # Handle the response
                 print(response)
@@ -1104,8 +1134,10 @@ class OsConfigZonalServiceAsyncClient:
                 "the individual field arguments should be set."
             )
 
-        request = instance_os_policies_compliance.GetInstanceOSPoliciesComplianceRequest(
-            request
+        request = (
+            instance_os_policies_compliance.GetInstanceOSPoliciesComplianceRequest(
+                request
+            )
         )
 
         # If we have keyword arguments corresponding to fields on the
@@ -1128,7 +1160,12 @@ class OsConfigZonalServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1148,14 +1185,13 @@ class OsConfigZonalServiceAsyncClient:
         r"""List OS policies compliance data for all Compute
         Engine VM instances in the specified zone.
 
-
         .. code-block:: python
 
             from google.cloud import osconfig_v1alpha
 
-            def sample_list_instance_os_policies_compliances():
+            async def sample_list_instance_os_policies_compliances():
                 # Create a client
-                client = osconfig_v1alpha.OsConfigZonalServiceClient()
+                client = osconfig_v1alpha.OsConfigZonalServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = osconfig_v1alpha.ListInstanceOSPoliciesCompliancesRequest(
@@ -1166,7 +1202,7 @@ class OsConfigZonalServiceAsyncClient:
                 page_result = client.list_instance_os_policies_compliances(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -1216,8 +1252,10 @@ class OsConfigZonalServiceAsyncClient:
                 "the individual field arguments should be set."
             )
 
-        request = instance_os_policies_compliance.ListInstanceOSPoliciesCompliancesRequest(
-            request
+        request = (
+            instance_os_policies_compliance.ListInstanceOSPoliciesCompliancesRequest(
+                request
+            )
         )
 
         # If we have keyword arguments corresponding to fields on the
@@ -1240,12 +1278,20 @@ class OsConfigZonalServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListInstanceOSPoliciesCompliancesAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -1265,14 +1311,13 @@ class OsConfigZonalServiceAsyncClient:
         r"""Get the OS policy asssignment report for the
         specified Compute Engine VM instance.
 
-
         .. code-block:: python
 
             from google.cloud import osconfig_v1alpha
 
-            def sample_get_os_policy_assignment_report():
+            async def sample_get_os_policy_assignment_report():
                 # Create a client
-                client = osconfig_v1alpha.OsConfigZonalServiceClient()
+                client = osconfig_v1alpha.OsConfigZonalServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = osconfig_v1alpha.GetOSPolicyAssignmentReportRequest(
@@ -1280,7 +1325,7 @@ class OsConfigZonalServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_os_policy_assignment_report(request=request)
+                response = await client.get_os_policy_assignment_report(request=request)
 
                 # Handle the response
                 print(response)
@@ -1352,7 +1397,12 @@ class OsConfigZonalServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1371,14 +1421,13 @@ class OsConfigZonalServiceAsyncClient:
         r"""List OS policy asssignment reports for all Compute
         Engine VM instances in the specified zone.
 
-
         .. code-block:: python
 
             from google.cloud import osconfig_v1alpha
 
-            def sample_list_os_policy_assignment_reports():
+            async def sample_list_os_policy_assignment_reports():
                 # Create a client
-                client = osconfig_v1alpha.OsConfigZonalServiceClient()
+                client = osconfig_v1alpha.OsConfigZonalServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = osconfig_v1alpha.ListOSPolicyAssignmentReportsRequest(
@@ -1389,7 +1438,7 @@ class OsConfigZonalServiceAsyncClient:
                 page_result = client.list_os_policy_assignment_reports(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -1477,12 +1526,20 @@ class OsConfigZonalServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListOSPolicyAssignmentReportsAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -1500,14 +1557,13 @@ class OsConfigZonalServiceAsyncClient:
         r"""Get inventory data for the specified VM instance. If the VM has
         no associated inventory, the message ``NOT_FOUND`` is returned.
 
-
         .. code-block:: python
 
             from google.cloud import osconfig_v1alpha
 
-            def sample_get_inventory():
+            async def sample_get_inventory():
                 # Create a client
-                client = osconfig_v1alpha.OsConfigZonalServiceClient()
+                client = osconfig_v1alpha.OsConfigZonalServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = osconfig_v1alpha.GetInventoryRequest(
@@ -1515,7 +1571,7 @@ class OsConfigZonalServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_inventory(request=request)
+                response = await client.get_inventory(request=request)
 
                 # Handle the response
                 print(response)
@@ -1590,7 +1646,12 @@ class OsConfigZonalServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1607,14 +1668,13 @@ class OsConfigZonalServiceAsyncClient:
         r"""List inventory data for all VM instances in the
         specified zone.
 
-
         .. code-block:: python
 
             from google.cloud import osconfig_v1alpha
 
-            def sample_list_inventories():
+            async def sample_list_inventories():
                 # Create a client
-                client = osconfig_v1alpha.OsConfigZonalServiceClient()
+                client = osconfig_v1alpha.OsConfigZonalServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = osconfig_v1alpha.ListInventoriesRequest(
@@ -1625,7 +1685,7 @@ class OsConfigZonalServiceAsyncClient:
                 page_result = client.list_inventories(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -1692,12 +1752,20 @@ class OsConfigZonalServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListInventoriesAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -1716,14 +1784,13 @@ class OsConfigZonalServiceAsyncClient:
         instance. Only VMs with inventory data have
         vulnerability reports associated with them.
 
-
         .. code-block:: python
 
             from google.cloud import osconfig_v1alpha
 
-            def sample_get_vulnerability_report():
+            async def sample_get_vulnerability_report():
                 # Create a client
-                client = osconfig_v1alpha.OsConfigZonalServiceClient()
+                client = osconfig_v1alpha.OsConfigZonalServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = osconfig_v1alpha.GetVulnerabilityReportRequest(
@@ -1731,7 +1798,7 @@ class OsConfigZonalServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_vulnerability_report(request=request)
+                response = await client.get_vulnerability_report(request=request)
 
                 # Handle the response
                 print(response)
@@ -1802,7 +1869,12 @@ class OsConfigZonalServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1819,14 +1891,13 @@ class OsConfigZonalServiceAsyncClient:
         r"""List vulnerability reports for all VM instances in
         the specified zone.
 
-
         .. code-block:: python
 
             from google.cloud import osconfig_v1alpha
 
-            def sample_list_vulnerability_reports():
+            async def sample_list_vulnerability_reports():
                 # Create a client
-                client = osconfig_v1alpha.OsConfigZonalServiceClient()
+                client = osconfig_v1alpha.OsConfigZonalServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = osconfig_v1alpha.ListVulnerabilityReportsRequest(
@@ -1837,7 +1908,7 @@ class OsConfigZonalServiceAsyncClient:
                 page_result = client.list_vulnerability_reports(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -1905,12 +1976,20 @@ class OsConfigZonalServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListVulnerabilityReportsAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -1925,7 +2004,9 @@ class OsConfigZonalServiceAsyncClient:
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution("google-cloud-os-config",).version,
+        gapic_version=pkg_resources.get_distribution(
+            "google-cloud-os-config",
+        ).version,
     )
 except pkg_resources.DistributionNotFound:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
