@@ -16,8 +16,7 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 import warnings
 
 from google.api_core import client_options as client_options_lib
@@ -25,10 +24,11 @@ from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
+from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -37,18 +37,22 @@ except AttributeError:  # pragma: NO COVER
 
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
-from google.cloud.osconfig_v1alpha.services.os_config_zonal_service import pagers
-from google.cloud.osconfig_v1alpha.types import config_common
-from google.cloud.osconfig_v1alpha.types import instance_os_policies_compliance
-from google.cloud.osconfig_v1alpha.types import inventory
-from google.cloud.osconfig_v1alpha.types import os_policy
-from google.cloud.osconfig_v1alpha.types import os_policy_assignment_reports
-from google.cloud.osconfig_v1alpha.types import os_policy_assignments
-from google.cloud.osconfig_v1alpha.types import vulnerability
 from google.protobuf import empty_pb2  # type: ignore
 from google.protobuf import field_mask_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
-from .transports.base import OsConfigZonalServiceTransport, DEFAULT_CLIENT_INFO
+
+from google.cloud.osconfig_v1alpha.services.os_config_zonal_service import pagers
+from google.cloud.osconfig_v1alpha.types import (
+    config_common,
+    instance_os_policies_compliance,
+    inventory,
+    os_policy,
+    os_policy_assignment_reports,
+    os_policy_assignments,
+    vulnerability,
+)
+
+from .transports.base import DEFAULT_CLIENT_INFO, OsConfigZonalServiceTransport
 from .transports.grpc import OsConfigZonalServiceGrpcTransport
 from .transports.grpc_asyncio import OsConfigZonalServiceGrpcAsyncIOTransport
 
@@ -68,7 +72,8 @@ class OsConfigZonalServiceClientMeta(type):
     _transport_registry["grpc_asyncio"] = OsConfigZonalServiceGrpcAsyncIOTransport
 
     def get_transport_class(
-        cls, label: str = None,
+        cls,
+        label: str = None,
     ) -> Type[OsConfigZonalServiceTransport]:
         """Returns an appropriate transport class.
 
@@ -178,10 +183,16 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         return self._transport
 
     @staticmethod
-    def instance_path(project: str, location: str, instance: str,) -> str:
+    def instance_path(
+        project: str,
+        location: str,
+        instance: str,
+    ) -> str:
         """Returns a fully-qualified instance string."""
         return "projects/{project}/locations/{location}/instances/{instance}".format(
-            project=project, location=location, instance=instance,
+            project=project,
+            location=location,
+            instance=instance,
         )
 
     @staticmethod
@@ -195,11 +206,15 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
 
     @staticmethod
     def instance_os_policies_compliance_path(
-        project: str, location: str, instance: str,
+        project: str,
+        location: str,
+        instance: str,
     ) -> str:
         """Returns a fully-qualified instance_os_policies_compliance string."""
         return "projects/{project}/locations/{location}/instanceOSPoliciesCompliances/{instance}".format(
-            project=project, location=location, instance=instance,
+            project=project,
+            location=location,
+            instance=instance,
         )
 
     @staticmethod
@@ -213,7 +228,10 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
 
     @staticmethod
     def instance_os_policy_assignment_path(
-        project: str, location: str, instance: str, assignment: str,
+        project: str,
+        location: str,
+        instance: str,
+        assignment: str,
     ) -> str:
         """Returns a fully-qualified instance_os_policy_assignment string."""
         return "projects/{project}/locations/{location}/instances/{instance}/osPolicyAssignments/{assignment}".format(
@@ -233,10 +251,16 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def inventory_path(project: str, location: str, instance: str,) -> str:
+    def inventory_path(
+        project: str,
+        location: str,
+        instance: str,
+    ) -> str:
         """Returns a fully-qualified inventory string."""
         return "projects/{project}/locations/{location}/instances/{instance}/inventory".format(
-            project=project, location=location, instance=instance,
+            project=project,
+            location=location,
+            instance=instance,
         )
 
     @staticmethod
@@ -250,7 +274,9 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
 
     @staticmethod
     def os_policy_assignment_path(
-        project: str, location: str, os_policy_assignment: str,
+        project: str,
+        location: str,
+        os_policy_assignment: str,
     ) -> str:
         """Returns a fully-qualified os_policy_assignment string."""
         return "projects/{project}/locations/{location}/osPolicyAssignments/{os_policy_assignment}".format(
@@ -270,7 +296,10 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
 
     @staticmethod
     def os_policy_assignment_report_path(
-        project: str, location: str, instance: str, assignment: str,
+        project: str,
+        location: str,
+        instance: str,
+        assignment: str,
     ) -> str:
         """Returns a fully-qualified os_policy_assignment_report string."""
         return "projects/{project}/locations/{location}/instances/{instance}/osPolicyAssignments/{assignment}/report".format(
@@ -290,10 +319,16 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def vulnerability_report_path(project: str, location: str, instance: str,) -> str:
+    def vulnerability_report_path(
+        project: str,
+        location: str,
+        instance: str,
+    ) -> str:
         """Returns a fully-qualified vulnerability_report string."""
         return "projects/{project}/locations/{location}/instances/{instance}/vulnerabilityReport".format(
-            project=project, location=location, instance=instance,
+            project=project,
+            location=location,
+            instance=instance,
         )
 
     @staticmethod
@@ -306,7 +341,9 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_billing_account_path(billing_account: str,) -> str:
+    def common_billing_account_path(
+        billing_account: str,
+    ) -> str:
         """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
@@ -319,9 +356,13 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_folder_path(folder: str,) -> str:
+    def common_folder_path(
+        folder: str,
+    ) -> str:
         """Returns a fully-qualified folder string."""
-        return "folders/{folder}".format(folder=folder,)
+        return "folders/{folder}".format(
+            folder=folder,
+        )
 
     @staticmethod
     def parse_common_folder_path(path: str) -> Dict[str, str]:
@@ -330,9 +371,13 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_organization_path(organization: str,) -> str:
+    def common_organization_path(
+        organization: str,
+    ) -> str:
         """Returns a fully-qualified organization string."""
-        return "organizations/{organization}".format(organization=organization,)
+        return "organizations/{organization}".format(
+            organization=organization,
+        )
 
     @staticmethod
     def parse_common_organization_path(path: str) -> Dict[str, str]:
@@ -341,9 +386,13 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_project_path(project: str,) -> str:
+    def common_project_path(
+        project: str,
+    ) -> str:
         """Returns a fully-qualified project string."""
-        return "projects/{project}".format(project=project,)
+        return "projects/{project}".format(
+            project=project,
+        )
 
     @staticmethod
     def parse_common_project_path(path: str) -> Dict[str, str]:
@@ -352,10 +401,14 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_location_path(project: str, location: str,) -> str:
+    def common_location_path(
+        project: str,
+        location: str,
+    ) -> str:
         """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
-            project=project, location=location,
+            project=project,
+            location=location,
         )
 
     @staticmethod
@@ -527,6 +580,7 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
                 quota_project_id=client_options.quota_project_id,
                 client_info=client_info,
                 always_use_jwt_access=True,
+                api_audience=client_options.api_audience,
             )
 
     def create_os_policy_assignment(
@@ -554,7 +608,6 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         For more information, see `Method:
         projects.locations.osPolicyAssignments.operations.cancel <https://cloud.google.com/compute/docs/osconfig/rest/v1alpha/projects.locations.osPolicyAssignments.operations/cancel>`__.
 
-
         .. code-block:: python
 
             from google.cloud import osconfig_v1alpha
@@ -687,7 +740,12 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -723,7 +781,6 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         For more information, see `Method:
         projects.locations.osPolicyAssignments.operations.cancel <https://cloud.google.com/compute/docs/osconfig/rest/v1alpha/projects.locations.osPolicyAssignments.operations/cancel>`__.
 
-
         .. code-block:: python
 
             from google.cloud import osconfig_v1alpha
@@ -838,7 +895,12 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -866,7 +928,6 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         retrieve a previous revision of the assignment, also provide the
         revision ID in the ``name`` parameter.
 
-
         .. code-block:: python
 
             from google.cloud import osconfig_v1alpha
@@ -953,7 +1014,12 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -974,7 +1040,6 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         For each OS policy assignment, the latest revision is
         returned.
 
-
         .. code-block:: python
 
             from google.cloud import osconfig_v1alpha
@@ -1055,12 +1120,20 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListOSPolicyAssignmentsPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -1080,7 +1153,6 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         r"""List the OS policy assignment revisions for a given
         OS policy assignment.
 
-
         .. code-block:: python
 
             from google.cloud import osconfig_v1alpha
@@ -1165,12 +1237,20 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListOSPolicyAssignmentRevisionsPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -1201,7 +1281,6 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         For more information, see `Method:
         projects.locations.osPolicyAssignments.operations.cancel <https://cloud.google.com/compute/docs/osconfig/rest/v1alpha/projects.locations.osPolicyAssignments.operations/cancel>`__.
 
-
         .. code-block:: python
 
             from google.cloud import osconfig_v1alpha
@@ -1257,9 +1336,6 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
 
                       }
 
-                   The JSON representation for Empty is empty JSON
-                   object {}.
-
         """
         # Create or coerce a protobuf request object.
         # Quick check: If we got a request object, we should *not* have
@@ -1297,7 +1373,12 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -1324,7 +1405,6 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         r"""Get OS policies compliance data for the specified
         Compute Engine VM instance.
 
-
         .. code-block:: python
 
             from google.cloud import osconfig_v1alpha
@@ -1412,8 +1492,10 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
             request,
             instance_os_policies_compliance.GetInstanceOSPoliciesComplianceRequest,
         ):
-            request = instance_os_policies_compliance.GetInstanceOSPoliciesComplianceRequest(
-                request
+            request = (
+                instance_os_policies_compliance.GetInstanceOSPoliciesComplianceRequest(
+                    request
+                )
             )
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
@@ -1433,7 +1515,12 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1453,7 +1540,6 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         r"""List OS policies compliance data for all Compute
         Engine VM instances in the specified zone.
 
-
         .. code-block:: python
 
             from google.cloud import osconfig_v1alpha
@@ -1550,12 +1636,20 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListInstanceOSPoliciesCompliancesPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -1575,7 +1669,6 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         r"""Get the OS policy asssignment report for the
         specified Compute Engine VM instance.
 
-
         .. code-block:: python
 
             from google.cloud import osconfig_v1alpha
@@ -1666,7 +1759,12 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1685,7 +1783,6 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         r"""List OS policy asssignment reports for all Compute
         Engine VM instances in the specified zone.
 
-
         .. code-block:: python
 
             from google.cloud import osconfig_v1alpha
@@ -1795,12 +1892,20 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListOSPolicyAssignmentReportsPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -1818,7 +1923,6 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         r"""Get inventory data for the specified VM instance. If the VM has
         no associated inventory, the message ``NOT_FOUND`` is returned.
 
-
         .. code-block:: python
 
             from google.cloud import osconfig_v1alpha
@@ -1908,7 +2012,12 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1925,7 +2034,6 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         r"""List inventory data for all VM instances in the
         specified zone.
 
-
         .. code-block:: python
 
             from google.cloud import osconfig_v1alpha
@@ -2010,12 +2118,20 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListInventoriesPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -2034,7 +2150,6 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         instance. Only VMs with inventory data have
         vulnerability reports associated with them.
 
-
         .. code-block:: python
 
             from google.cloud import osconfig_v1alpha
@@ -2120,7 +2235,12 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -2137,7 +2257,6 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         r"""List vulnerability reports for all VM instances in
         the specified zone.
 
-
         .. code-block:: python
 
             from google.cloud import osconfig_v1alpha
@@ -2225,12 +2344,20 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListVulnerabilityReportsPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -2252,7 +2379,9 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution("google-cloud-os-config",).version,
+        gapic_version=pkg_resources.get_distribution(
+            "google-cloud-os-config",
+        ).version,
     )
 except pkg_resources.DistributionNotFound:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
