@@ -15,7 +15,6 @@
 #
 import proto  # type: ignore
 
-
 __protobuf__ = proto.module(
     package="google.cloud.osconfig.v1alpha",
     manifest={
@@ -67,9 +66,20 @@ class OSPolicyResourceConfigStep(proto.Message):
         SUCCEEDED = 1
         FAILED = 2
 
-    type_ = proto.Field(proto.ENUM, number=1, enum=Type,)
-    outcome = proto.Field(proto.ENUM, number=2, enum=Outcome,)
-    error_message = proto.Field(proto.STRING, number=3,)
+    type_ = proto.Field(
+        proto.ENUM,
+        number=1,
+        enum=Type,
+    )
+    outcome = proto.Field(
+        proto.ENUM,
+        number=2,
+        enum=Outcome,
+    )
+    error_message = proto.Field(
+        proto.STRING,
+        number=3,
+    )
 
 
 class OSPolicyResourceCompliance(proto.Message):
@@ -100,15 +110,30 @@ class OSPolicyResourceCompliance(proto.Message):
                 run). Output size is limited to 100K bytes.
         """
 
-        enforcement_output = proto.Field(proto.BYTES, number=2,)
+        enforcement_output = proto.Field(
+            proto.BYTES,
+            number=2,
+        )
 
-    os_policy_resource_id = proto.Field(proto.STRING, number=1,)
+    os_policy_resource_id = proto.Field(
+        proto.STRING,
+        number=1,
+    )
     config_steps = proto.RepeatedField(
-        proto.MESSAGE, number=2, message="OSPolicyResourceConfigStep",
+        proto.MESSAGE,
+        number=2,
+        message="OSPolicyResourceConfigStep",
+    )
+    state = proto.Field(
+        proto.ENUM,
+        number=3,
+        enum="OSPolicyComplianceState",
     )
-    state = proto.Field(proto.ENUM, number=3, enum="OSPolicyComplianceState",)
     exec_resource_output = proto.Field(
-        proto.MESSAGE, number=4, oneof="output", message=ExecResourceOutput,
+        proto.MESSAGE,
+        number=4,
+        oneof="output",
+        message=ExecResourceOutput,
     )
 
 
